@@ -1,10 +1,12 @@
 import pickle
 import unittest
 import os
+from distutils.version import LooseVersion
 
 import numpy as np
 import scipy.sparse as sp
 
+import Orange
 from Orange.data import (
     ContinuousVariable, DiscreteVariable, StringVariable,
     Domain, Table, IsDefined, FilterContinuous, Values, FilterString,
@@ -13,6 +15,18 @@ from Orange.util import OrangeDeprecationWarning
 
 
 class TestTableInit(unittest.TestCase):
+
+    def test_is_view_is_copy_deprecated(self):
+        """This test is to be included in the 3.32 release and will fail in
+        version 3.34. This serves as a reminder to remove the deprecated methods
+        and this test."""
+        if LooseVersion(Orange.__version__) >= LooseVersion("3.34"):
+            self.fail(
+                "`Orange.data.Table.is_view` and `Orange.data.Table.is_copy` "
+                "were deprecated in version 3.32, and there have been two minor "
+                "versions in between. Please remove the deprecated methods."
+            )
+
     def test_empty_table(self):
         t = Table()
         self.assertEqual(t.domain.attributes, ())
@@ -40,7 +54,7 @@ class TestTableInit(unittest.TestCase):
         Y = np.arange(5) % 2
         metas = np.array(list("abcde")).reshape(5, 1)
         W = np.arange(5) / 5
-        ids = np.arange(100, 105, dtype=np.int)
+        ids = np.arange(100, 105, dtype=int)
         attributes = dict(a=5, b="foo")
 
         dom = Domain([ContinuousVariable(x) for x in "abcd"],
@@ -380,8 +394,13 @@ class TestTableLocking(unittest.TestCase):
             Table.LOCKING = default
 
         unpickled = pickle.loads(pickle.dumps(table))
+<<<<<<< HEAD
         self.assertFalse(unpickled.is_view())
         self.assertTrue(unpickled.is_copy())
+=======
+        self.assertTrue(all(ar.base is None
+                            for ar in (unpickled.X, unpickled.Y, unpickled.W, unpickled.metas)))
+>>>>>>> upstream/master
         with unpickled.unlocked():
             unpickled.X[0, 0] = 42
 
