@@ -4,7 +4,6 @@ import textwrap
 
 from Orange.widgets import widget, gui
 from Orange.widgets.utils.widgetpreview import WidgetPreview
-from Orange.widgets.utils.state_summary import format_summary_details
 from Orange.widgets.widget import Input
 from Orange.data.table import Table
 from Orange.data import StringVariable, DiscreteVariable, ContinuousVariable
@@ -21,13 +20,14 @@ class OWDataInfo(widget.OWWidget):
     description = """显示数据集的基本信息，例如列中变量的数量和类型以及行数。"""
     icon = "icons/DataInfo.svg"
     priority = 80
-    category = "Data"
-    keywords = ["info", 'shuju', 'xinxi', 'shujuxinxi']
+    category = "数据(Data)"
+    keywords = ['shuju', 'xinxi', "information", "inspect"]
 
     class Inputs:
         data = Input("数据(Data)", Table, replaces=['Data'])
 
     want_main_area = False
+    buttons_area_orientation = None
     resizing_enabled = False
 
     def __init__(self):
@@ -35,16 +35,12 @@ class OWDataInfo(widget.OWWidget):
 
         self._clear_fields()
 
-        for box in (["Data Set Name","数据集名称"], ["Data Set Size","数据集大小"], ["Features","特征"], ["Targets","目标"],
-                    ["Meta Attributes","元属性"], ["Location","位置"], ["Data Attributes","数据属性"]):
+        for box in (["Data Set Name", "数据集名称"], ["Data Set Size", "数据集大小"], ["Features", "特征"], ["Targets", "目标"],
+                    ["Meta Attributes", "元属性"], ["Location", "位置"], ["Data Attributes", "数据属性"]):
             name = box[0].lower().replace(" ", "_")
-            chinese_name = box[1]
-            bo = gui.vBox(self.controlArea, chinese_name,
-                          addSpace=False and box[0] != "Meta Attributes")
+            bo = gui.vBox(self.controlArea, box[1])
             gui.label(bo, self, "%%(%s)s" % name)
 
-        self.info.set_input_summary(self.info.NoInput)
-
         # ensure the widget has some decent minimum width.
         self.targets = "Categorical outcome with 123 values"
         self.layout().activate()
@@ -59,12 +55,9 @@ class OWDataInfo(widget.OWWidget):
     def data(self, data):
         if data is None:
             self._clear_fields()
-            self.info.set_input_summary(self.info.NoInput)
         else:
             self._set_fields(data)
             self._set_report(data)
-            self.info.set_input_summary(data.approx_len(),
-                                        format_summary_details(data))
 
     def _clear_fields(self):
         self.data_set_name = ""
@@ -95,7 +88,7 @@ class OWDataInfo(widget.OWWidget):
 
         def pack_counts(s, include_non_primitive=False):
             if not s:
-                return "无(None)"
+                return "无"
             return pack_table(
                 (name, n_or_none(self._count(s, type_)))
                 for name, type_ in (
@@ -117,12 +110,12 @@ class OWDataInfo(widget.OWWidget):
             sparseness = ""
         self.data_set_size = pack_table((
             ("Rows", '~{}'.format(data.approx_len())),
-            ("Columns", len(domain)+len(domain.metas)))) + sparseness
+            ("Columns", len(domain.variables)+len(domain.metas)))) + sparseness
 
         def update_size():
             self.data_set_size = pack_table((
                 ("行", len(data)),
-                ("列", len(domain)+len(domain.metas)))) + sparseness
+                ("列", len(domain.variables)+len(domain.metas)))) + sparseness
 
         threading.Thread(target=update_size).start()
 
@@ -195,7 +188,8 @@ class OWDataInfo(widget.OWWidget):
             cont_class = count(domain.class_vars, ContinuousVariable)
             tt = ""
             if disc_class:
-                tt += report.plural("{number} categorical outcome{s}", disc_class)
+                tt += report.plural("{number} categorical outcome{s}",
+                                    disc_class)
             if cont_class:
                 tt += report.plural("{number} numeric target{s}", cont_class)
         dd["Meta attributes"] = len(domain.metas) > 0 and join_if((
