@@ -190,7 +190,7 @@ class OWDataTable(OWWidget):
         data = MultiInput("数据(Data)", Table, auto_summary=False, filter_none=True, replaces=['Data'])
 
     class Outputs:
-        selected_data = Output("选定的数据(Selected Data)",
+        selected_data = Output("选中的数据(Selected Data)",
                                Table, default=True, replaces=['Selected Data'])
         annotated_data = Output('数据(Data)', Table, replaces=['Data'])
 
