@@ -1,3 +1,4 @@
+#pylint: disable=unsubscriptable-object
 import datetime
 import unittest
 from collections import namedtuple
@@ -9,6 +10,8 @@ import numpy as np
 from AnyQt.QtCore import QItemSelection, QItemSelectionRange, \
     QItemSelectionModel, Qt
 
+from orangewidget.settings import Context
+
 from Orange.data import Table, Domain, StringVariable, ContinuousVariable, \
     DiscreteVariable, TimeVariable
 from Orange.widgets.tests.base import WidgetTest, datasets
@@ -42,23 +45,23 @@ continuous = [
 
 # Unordered discrete variable variations
 rgb_full = VarDataPair(
-    DiscreteVariable('rgb_full', values=['r', 'g', 'b']),
+    DiscreteVariable('rgb_full', values=('r', 'g', 'b')),
     np.array([0, 1, 1, 1, 2], dtype=float),
 )
 rgb_missing = VarDataPair(
-    DiscreteVariable('rgb_missing', values=['r', 'g', 'b']),
+    DiscreteVariable('rgb_missing', values=('r', 'g', 'b')),
     np.array([0, 1, 1, np.nan, 2], dtype=float),
 )
 rgb_all_missing = VarDataPair(
-    DiscreteVariable('rgb_all_missing', values=['r', 'g', 'b']),
+    DiscreteVariable('rgb_all_missing', values=('r', 'g', 'b')),
     np.array([np.nan] * 5, dtype=float),
 )
 rgb_bins_missing = VarDataPair(
-    DiscreteVariable('rgb_bins_missing', values=['r', 'g', 'b']),
+    DiscreteVariable('rgb_bins_missing', values=('r', 'g', 'b')),
     np.array([np.nan, 1, 1, 1, np.nan], dtype=float),
 )
 rgb_same = VarDataPair(
-    DiscreteVariable('rgb_same', values=['r', 'g', 'b']),
+    DiscreteVariable('rgb_same', values=('r', 'g', 'b')),
     np.array([2] * 5, dtype=float),
 )
 rgb = [
@@ -67,23 +70,23 @@ rgb = [
 
 # Ordered discrete variable variations
 ints_full = VarDataPair(
-    DiscreteVariable('ints_full', values=['2', '3', '4'], ordered=True),
+    DiscreteVariable('ints_full', values=('2', '3', '4')),
     np.array([0, 1, 1, 1, 2], dtype=float),
 )
 ints_missing = VarDataPair(
-    DiscreteVariable('ints_missing', values=['2', '3', '4'], ordered=True),
+    DiscreteVariable('ints_missing', values=('2', '3', '4')),
     np.array([0, 1, 1, np.nan, 2], dtype=float),
 )
 ints_all_missing = VarDataPair(
-    DiscreteVariable('ints_all_missing', values=['2', '3', '4'], ordered=True),
+    DiscreteVariable('ints_all_missing', values=('2', '3', '4')),
     np.array([np.nan] * 5, dtype=float),
 )
 ints_bins_missing = VarDataPair(
-    DiscreteVariable('ints_bins_missing', values=['2', '3', '4'], ordered=True),
+    DiscreteVariable('ints_bins_missing', values=('2', '3', '4')),
     np.array([np.nan, 1, 1, 1, np.nan], dtype=float),
 )
 ints_same = VarDataPair(
-    DiscreteVariable('ints_same', values=['2', '3', '4'], ordered=True),
+    DiscreteVariable('ints_same', values=('2', '3', '4')),
     np.array([0] * 5, dtype=float),
 )
 ints = [
@@ -101,7 +104,7 @@ def _to_timestamps(years):
 # Time variable variations, windows timestamps need to be valid timestamps so
 # we'll just fill it in with arbitrary years
 time_full = VarDataPair(
-    TimeVariable('time_full'),
+    TimeVariable('time_full', have_date=True, have_time=True),
     np.array(_to_timestamps([2000, 2001, 2002, 2003, 2004]), dtype=float),
 )
 time_missing = VarDataPair(
@@ -113,11 +116,15 @@ time_all_missing = VarDataPair(
     np.array(_to_timestamps([np.nan] * 5), dtype=float),
 )
 time_same = VarDataPair(
-    TimeVariable('time_same'),
+    TimeVariable('time_same', have_date=True, have_time=True),
     np.array(_to_timestamps([2004] * 5), dtype=float),
 )
+time_negative = VarDataPair(
+    TimeVariable('time_negative', have_date=True, have_time=True),
+    np.array([0, -1, 24 * 60 * 60], dtype=float),
+)
 time = [
-    time_full, time_missing, time_all_missing, time_same
+    time_full, time_missing, time_all_missing, time_same, time_negative
 ]
 
 # String variable variations
@@ -243,6 +250,12 @@ class TestVariousDataSets(WidgetTest):
         self.send_signal(self.widget.Inputs.data, prepare_table(data))
         self.run_through_variables()
 
+    @table_dense_sparse
+    def test_on_data_with_negative_timestamps(self, prepare_table):
+        data = make_table([time_negative])
+        self.send_signal(self.widget.Inputs.data, prepare_table(data))
+        self.run_through_variables()
+
     def test_switching_to_dataset_with_no_target_var(self):
         """Switching from data set with target variable to a data set with
         no target variable should not result in crash."""
@@ -275,6 +288,15 @@ class TestVariousDataSets(WidgetTest):
             except Exception as e:
                 raise AssertionError(f"Failed on `{data.name}`") from e
 
+    def test_header_resize_aspect_ratio(self):
+        self.widget.show()  # must be visible for header resize to work
+        size = self.widget.size()
+        self.widget.resize(size.width() + 2000, size.height())
+        self.assertEqual(
+            self.widget.table_view.verticalHeader().defaultSectionSize(),
+            self.widget.table_view.MAXIMUM_HISTOGRAM_HEIGHT
+        )
+
 
 def select_rows(rows: List[int], widget: OWFeatureStatistics):
     """Since the widget sorts the rows, selecting rows isn't trivial."""
@@ -303,7 +325,7 @@ class TestFeatureStatisticsOutputs(WidgetTest):
         self.send_signal(self.widget.Inputs.data, self.data)
         self.select_rows = partial(select_rows, widget=self.widget)
 
-    def test_changing_data_updates_ouput(self):
+    def test_changing_data_updates_output(self):
         # Test behaviour of widget when auto commit is OFF
         self.widget.auto_commit = False
 
@@ -312,33 +334,27 @@ class TestFeatureStatisticsOutputs(WidgetTest):
         self.select_rows([0])
         # By default, nothing should be sent since auto commit is off
         self.assertIsNone(self.get_output(self.widget.Outputs.reduced_data))
-        self.assertIsNone(self.get_output(self.widget.Outputs.statistics))
         # When we commit, the data should be on the output
         self.widget.unconditional_commit()
         self.assertIsNotNone(self.get_output(self.widget.Outputs.reduced_data))
-        self.assertIsNotNone(self.get_output(self.widget.Outputs.statistics))
 
         # Send some new data
         iris = Table('iris')
         self.send_signal(self.widget.Inputs.data, iris)
         # By default, there should be nothing on the output
         self.assertIsNone(self.get_output(self.widget.Outputs.reduced_data))
-        self.assertIsNone(self.get_output(self.widget.Outputs.statistics))
         # Nothing should change after commit, since we haven't selected any rows
         self.widget.unconditional_commit()
         self.assertIsNone(self.get_output(self.widget.Outputs.reduced_data))
-        self.assertIsNone(self.get_output(self.widget.Outputs.statistics))
 
         # Now let's switch back to the original data, where we selected row 0
         self.send_signal(self.widget.Inputs.data, self.data)
         # Again, since auto commit is off, nothing should be on the output
         self.assertIsNone(self.get_output(self.widget.Outputs.reduced_data))
-        self.assertIsNone(self.get_output(self.widget.Outputs.statistics))
         # Since the row selection is saved into context settings, the appropriate
         # thing should be sent to output
         self.widget.unconditional_commit()
         self.assertIsNotNone(self.get_output(self.widget.Outputs.reduced_data))
-        self.assertIsNotNone(self.get_output(self.widget.Outputs.statistics))
 
     def test_changing_data_updates_output_with_autocommit(self):
         # Test behaviour of widget when auto commit is ON
@@ -349,20 +365,17 @@ class TestFeatureStatisticsOutputs(WidgetTest):
         self.select_rows([0])
         # Selecting rows should send data to output
         self.assertIsNotNone(self.get_output(self.widget.Outputs.reduced_data))
-        self.assertIsNotNone(self.get_output(self.widget.Outputs.statistics))
 
         # Send some new data
         iris = Table('iris')
         self.send_signal(self.widget.Inputs.data, iris)
         # Don't select anything, so the outputs should be empty
         self.assertIsNone(self.get_output(self.widget.Outputs.reduced_data))
-        self.assertIsNone(self.get_output(self.widget.Outputs.statistics))
 
         # Now let's switch back to the original data, where we had selected row 0,
         # we expect that to be sent to output
         self.send_signal(self.widget.Inputs.data, self.data)
         self.assertIsNotNone(self.get_output(self.widget.Outputs.reduced_data))
-        self.assertIsNotNone(self.get_output(self.widget.Outputs.statistics))
 
     def test_sends_single_attribute_table_to_output(self):
         # Check if selecting a single attribute row
@@ -431,12 +444,31 @@ class TestFeatureStatisticsOutputs(WidgetTest):
         self.select_rows([0])
         self.widget.unconditional_commit()
         self.assertIsNotNone(self.get_output(self.widget.Outputs.reduced_data))
-        self.assertIsNotNone(self.get_output(self.widget.Outputs.statistics))
 
         self.widget.table_view.clearSelection()
         self.widget.unconditional_commit()
         self.assertIsNone(self.get_output(self.widget.Outputs.reduced_data))
-        self.assertIsNone(self.get_output(self.widget.Outputs.statistics))
+
+    def test_output_combinations(self):
+        # No selection -> reduced_data is not output, statistics is present
+        self.widget.unconditional_commit()
+        self.assertIsNone(self.get_output(self.widget.Outputs.reduced_data))
+        self.assertEqual(len(self.get_output(self.widget.Outputs.statistics)),
+                         self.widget.model.rowCount())
+
+        # Has selection -> all outputs present
+        self.select_rows([0, 1])
+        self.widget.unconditional_commit()
+        outp = self.get_output(self.widget.Outputs.reduced_data)
+        self.assertEqual(len(outp), len(self.data))
+        self.assertEqual(len(outp.domain.variables), 2)
+        self.assertEqual(len(self.get_output(self.widget.Outputs.statistics)),
+                         self.widget.model.rowCount())
+
+        # No data -> no output
+        self.send_signal(self.widget.Inputs.data, None)
+        self.assertIsNone(self.get_output(self.widget.Outputs.reduced_data))
+        self.assertIsNone(self.get_output(self.widget.Outputs.reduced_data))
 
 
 class TestFeatureStatisticsUI(WidgetTest):
@@ -451,17 +483,62 @@ class TestFeatureStatisticsUI(WidgetTest):
     def test_restores_previous_selection(self):
         """Widget should remember selection with domain context handler."""
         # Send data and select rows
+        domain1 = self.data1.domain
         self.send_signal(self.widget.Inputs.data, self.data1)
         self.select_rows([0, 2])
-        self.assertEqual(len(self.widget.selected_rows), 2)
+        self.assertEqual(set(self.widget.selected_vars),
+                         {domain1[0], domain1[2]})
 
         # Sending new data clears selection
         self.send_signal(self.widget.Inputs.data, self.data2)
-        self.assertEqual(len(self.widget.selected_rows), 0)
+        self.assertEqual(len(self.widget.selected_vars), 0)
 
         # Sending back the old data restores the selection
+        iris3 = self.data1.transform(
+            Domain([domain1[2], domain1[0], domain1[1]], domain1.class_var))
+        self.send_signal(self.widget.Inputs.data, iris3)
+        self.assertEqual(set(self.widget.selected_vars),
+                         {domain1[0], domain1[2]})
+
+    def test_settings_migration_to_ver21(self):
+        settings = {
+            'controlAreaVisible': True, 'savedWidgetGeometry': '',
+            '__version__': 1,
+            'context_settings': [
+                Context(
+                    values={'auto_commit': (True, -2),
+                            'color_var': ('iris', 101),
+                            'selected_rows': [1, 4],
+                            'sorting': ((1, 0), -2), '__version__': 1},
+                    attributes={'petal length': 2, 'petal width': 2,
+                                'sepal length': 2, 'sepal width': 2},
+                    metas={'iris': 1})]
+        }
+        widget = self.create_widget(OWFeatureStatistics,
+                                    stored_settings=settings)
+        self.send_signal(widget.Inputs.data, self.data1)
+        domain = self.data1.domain
+        self.assertEqual(widget.selected_vars, [domain["petal width"],
+                                                domain["iris"]])
+
+    def test_report(self):
         self.send_signal(self.widget.Inputs.data, self.data1)
-        self.assertEqual(len(self.widget.selected_rows), 2)
+
+        self.widget.report_button.click()
+        report_text = self.widget.report_html
+
+        self.assertIn("<table>", report_text)
+        self.assertEqual(6, report_text.count("<tr>"))  # header + 5 rows
+
+
+class TestSummary(WidgetTest):
+    def setUp(self):
+        self.widget = self.create_widget(OWFeatureStatistics)
+        self.data = make_table(
+            [continuous_full, continuous_missing],
+            target=[rgb_full, rgb_missing], metas=[ints_full, ints_missing]
+        )
+        self.select_rows = partial(select_rows, widget=self.widget)
 
 
 if __name__ == "__main__":
