@@ -1,7 +1,7 @@
 # Test methods with long descriptive names can omit docstrings
 # pylint: disable=missing-docstring,unsubscriptable-object
 import unittest
-from unittest.mock import patch, Mock
+from unittest.mock import patch
 from pickle import loads, dumps
 
 import numpy as np
@@ -9,8 +9,6 @@ import numpy as np
 from AnyQt.QtCore import Qt, QPoint
 from AnyQt.QtTest import QTest
 
-from orangewidget.widget import StateInfo
-
 from Orange.data import (Table, Domain, ContinuousVariable as Cv,
                          StringVariable as sv, DiscreteVariable as Dv,
                          TimeVariable as Tv)
@@ -18,8 +16,6 @@ from Orange.widgets.data.owpivot import (OWPivot, Pivot,
                                          AggregationFunctionsEnum)
 from Orange.widgets.tests.base import WidgetTest
 from Orange.widgets.tests.utils import simulate
-from Orange.widgets.utils.state_summary import format_summary_details, \
-    format_multiple_summaries
 
 
 class TestOWPivot(WidgetTest):
@@ -245,39 +241,6 @@ class TestOWPivot(WidgetTest):
         self.send_signal(self.widget.Inputs.data, None)
         self.widget.report_button.click()
 
-    def test_summary(self):
-        """Check if the status bar is updated when data is received"""
-        data = self.iris
-        input_sum = self.widget.info.set_input_summary = Mock()
-        output_sum = self.widget.info.set_output_summary = Mock()
-
-        self.send_signal(self.widget.Inputs.data, data)
-        input_sum.assert_called_with(len(data), format_summary_details(data))
-        output = self.get_output(self.widget.Outputs.filtered_data)
-        self.assertIsNone(output)
-        simulate.combobox_activate_item(self.widget.controls.row_feature,
-                                        self.iris.domain.attributes[0].name)
-        simulate.combobox_activate_item(self.widget.controls.col_feature,
-                                        self.iris.domain.class_var.name)
-        self.widget.table_view.set_selection(set([(11, 0), (11, 1), (12, 0)]))
-        self.widget.table_view.selection_changed.emit()
-        filtered = self.get_output(self.widget.Outputs.filtered_data)
-        pivot = self.get_output(self.widget.Outputs.pivot_table)
-        grouped = self.get_output(self.widget.Outputs.grouped_data)
-        output_sum.assert_called_with(
-            f"{len(pivot)}, {len(filtered)}, {len(grouped)}",
-            format_multiple_summaries([("Pivot table", pivot),
-                                       ("Filtered data", filtered),
-                                       ("Grouped data", grouped)]),
-            format=1)
-        input_sum.reset_mock()
-        output_sum.reset_mock()
-        self.send_signal(self.widget.Inputs.data, None)
-        input_sum.assert_called_once()
-        self.assertIsInstance(input_sum.call_args[0][0], StateInfo.Empty)
-        output_sum.assert_called_once()
-        self.assertIsInstance(output_sum.call_args[0][0], StateInfo.Empty)
-
     def test_renaming_warning(self):
         data = Table('iris')
         cls_var = data.domain.class_var.copy(name='Aggregate')
@@ -315,6 +278,32 @@ class TestOWPivot(WidgetTest):
         self.assertEqual(model.data(model.index(4, 4)), "114.0")
         self.assertEqual(model.data(model.index(5, 4)), "reversable defect")
 
+    def test_only_metas_table(self):
+        self.send_signal(self.widget.Inputs.data, self.zoo[:, 17:])
+        self.assertTrue(self.widget.Warning.no_variables.is_shown())
+
+        data = self.zoo.transform(Domain([], metas=self.zoo.domain.attributes))
+        self.send_signal(self.widget.Inputs.data, data)
+        self.assertFalse(self.widget.Warning.no_variables.is_shown())
+
+    def test_empty_table(self):
+        data = self.heart_disease[:, :0]
+        self.send_signal(self.widget.Inputs.data, data)
+        self.assertTrue(self.widget.Warning.no_variables.is_shown())
+        self.send_signal(self.widget.Inputs.data, None)
+        self.assertFalse(self.widget.Warning.no_variables.is_shown())
+
+        data = self.heart_disease
+        self.send_signal(self.widget.Inputs.data, data)
+
+        zoo_domain = self.zoo.domain
+        data = self.zoo.transform(Domain([], metas=zoo_domain.metas))
+        self.send_signal(self.widget.Inputs.data, data)
+
+        domain = Domain([], zoo_domain.class_vars, metas=zoo_domain.metas)
+        data = self.zoo.transform(domain)
+        self.send_signal(self.widget.Inputs.data, data)
+
 
 class TestAggregationFunctionsEnum(unittest.TestCase):
     def test_pickle(self):
@@ -382,8 +371,9 @@ class TestPivot(unittest.TestCase):
                          Dv("d2", ("a", "b")), Cv("c2")])
         X = np.array([[0, 1, 0, 2], [1, 2, np.nan, 3], [0, 3, 1, np.nan]])
         table = Table(domain, X).transform(
-            Domain(domain.attributes[:2], metas=domain.attributes[2:]))
-        table.metas = table.metas.astype(object)
+            Domain(domain.attributes[:2], metas=domain.attributes[2:])).copy()
+        with table.unlocked():
+            table.metas = table.metas.astype(object)
 
         pivot = Pivot(table, Pivot.Functions, table.domain[-1])
         group_tab = pivot.group_table
