@@ -97,7 +97,7 @@ class OWConfusionMatrix(widget.OWWidget):
 
     class Outputs:
         selected_data = Output(
-            "选定的数据(Selected Data)", Orange.data.Table, default=True, replaces=['Selected Data'])
+            "选中的数据(Selected Data)", Orange.data.Table, default=True, replaces=['Selected Data'])
         annotated_data = Output(
             '数据(Data)', Orange.data.Table, replaces=['Data'])
 
