@@ -1,13 +1,16 @@
 import os
 import pickle
+from typing import Any, Dict
 
 from AnyQt.QtWidgets import QSizePolicy, QStyle, QFileDialog
 from AnyQt.QtCore import QTimer
 
+from orangewidget.workflow.drophandler import SingleFileDropHandler
+
 from Orange.base import Model
 from Orange.widgets import widget, gui
 from Orange.widgets.model import owsavemodel
-from Orange.widgets.utils.filedialogs import RecentPathsWComboMixin
+from Orange.widgets.utils.filedialogs import RecentPathsWComboMixin, RecentPath
 from Orange.widgets.utils import stdpaths
 from Orange.widgets.utils.widgetpreview import WidgetPreview
 from Orange.widgets.widget import Msg, Output
@@ -19,8 +22,8 @@ class OWLoadModel(widget.OWWidget, RecentPathsWComboMixin):
     priority = 3050
     replaces = ["Orange.widgets.classify.owloadclassifier.OWLoadClassifier"]
     icon = "icons/LoadModel.svg"
-    keywords = ["file", "open", "model", 'zairumoxing', 'jiazaimoxing', 'moxing']
-    category = 'model'
+    keywords = ['zairumoxing', 'jiazaimoxing']
+    category = '模型(Model)'
 
     class Outputs:
         model = Output("模型(Model)", Model, replaces=['Model'])
@@ -31,6 +34,7 @@ class OWLoadModel(widget.OWWidget, RecentPathsWComboMixin):
     FILTER = ";;".join(owsavemodel.OWSaveModel.filters)
 
     want_main_area = False
+    buttons_area_orientation = None
     resizing_enabled = False
 
     def __init__(self):
@@ -38,7 +42,7 @@ class OWLoadModel(widget.OWWidget, RecentPathsWComboMixin):
         RecentPathsWComboMixin.__init__(self)
         self.loaded_file = ""
 
-        vbox = gui.vBox(self.controlArea, "文件", addSpace=True)
+        vbox = gui.vBox(self.controlArea, "文件")
         box = gui.hBox(vbox)
         self.file_combo.setMinimumWidth(300)
         box.layout().addWidget(self.file_combo)
@@ -88,5 +92,18 @@ class OWLoadModel(widget.OWWidget, RecentPathsWComboMixin):
             self.Outputs.model.send(model)
 
 
+class OWLoadModelDropHandler(SingleFileDropHandler):
+    WIDGET = OWLoadModel
+
+    def canDropFile(self, path: str) -> bool:
+        return path.endswith(".pkcls")
+
+    def parametersFromFile(self, path: str) -> Dict[str, Any]:
+        r = RecentPath(os.path.abspath(path), None, None,
+                       os.path.basename(path))
+        parameters = {"recent_paths": [r]}
+        return parameters
+
+
 if __name__ == "__main__":  # pragma: no cover
     WidgetPreview(OWLoadModel).run()
