@@ -1,11 +1,11 @@
-from collections import OrderedDict
+from typing import List
 
 from Orange.base import Learner
 from Orange.data import Table
 from Orange.ensembles.stack import StackedFitter
 from Orange.widgets.settings import Setting
 from Orange.widgets.utils.owlearnerwidget import OWBaseLearner
-from Orange.widgets.widget import Input
+from Orange.widgets.widget import Input, MultiInput
 
 
 class OWStackedLearner(OWBaseLearner):
@@ -13,19 +13,19 @@ class OWStackedLearner(OWBaseLearner):
     description = "堆叠多个模型。"
     icon = "icons/Stacking.svg"
     priority = 100
-    category = 'model'
-    keywords = ['duidie']
+    category = '模型(Model)'
 
     LEARNER = StackedFitter
 
     learner_name = Setting("堆叠(Stacking)")
 
     class Inputs(OWBaseLearner.Inputs):
-        learners = Input("学习器(Learners)", Learner, multiple=True, replaces=['Learners'])
+        learners = MultiInput("学习器(Learners)", Learner,
+                              filter_none=True, replaces=['Learners'])
         aggregate = Input("组合方法(Aggregate)", Learner, replaces=['Aggregate'])
 
     def __init__(self):
-        self.learners = OrderedDict()
+        self.learners: List[Learner] = []
         self.aggregate = None
         super().__init__()
 
@@ -33,27 +33,38 @@ class OWStackedLearner(OWBaseLearner):
         pass
 
     @Inputs.learners
-    def set_learners(self, learner, id):  # pylint: disable=redefined-builtin
-        if id in self.learners and learner is None:
-            del self.learners[id]
-        elif learner is not None:
-            self.learners[id] = learner
-        self.apply()
+    def set_learner(self, index: int, learner: Learner):
+        self.learners[index] = learner
+        self._invalidate()
+
+    @Inputs.learners.insert
+    def insert_learner(self, index, learner):
+        self.learners.insert(index, learner)
+        self._invalidate()
+
+    @Inputs.learners.remove
+    def remove_learner(self, index):
+        self.learners.pop(index)
+        self._invalidate()
 
     @Inputs.aggregate
     def set_aggregate(self, aggregate):
         self.aggregate = aggregate
-        self.apply()
+        self._invalidate()
+
+    def _invalidate(self):
+        self.learner = self.model = None
+        # ... and handleNewSignals will do the rest
 
     def create_learner(self):
         if not self.learners:
             return None
         return self.LEARNER(
-            tuple(self.learners.values()), aggregate=self.aggregate,
+            tuple(self.learners), aggregate=self.aggregate,
             preprocessors=self.preprocessors)
 
     def get_learner_parameters(self):
-        return (("Base learners", [l.name for l in self.learners.values()]),
+        return (("Base learners", [l.name for l in self.learners]),
                 ("Aggregator",
                  self.aggregate.name if self.aggregate else 'default'))
 
@@ -67,5 +78,5 @@ if __name__ == "__main__":
     d = Table(sys.argv[1] if len(sys.argv) > 1 else 'iris')
     ow.set_data(d)
     ow.show()
-    a.exec_()
+    a.exec()
     ow.saveSettings()
