@@ -3,10 +3,12 @@ import os
 from AnyQt.QtWidgets import QSizePolicy, QStyle, QMessageBox, QFileDialog
 from AnyQt.QtCore import QTimer
 
+from orangewidget.workflow.drophandler import SingleFileDropHandler
+
 from Orange.misc import DistMatrix
 from Orange.widgets import widget, gui
 from Orange.data import get_sample_datasets_dir
-from Orange.widgets.utils.filedialogs import RecentPathsWComboMixin
+from Orange.widgets.utils.filedialogs import RecentPathsWComboMixin, RecentPath
 from Orange.widgets.utils.widgetpreview import WidgetPreview
 from Orange.widgets.widget import Output
 
@@ -19,6 +21,7 @@ class OWDistanceFile(widget.OWWidget, RecentPathsWComboMixin):
     priority = 10
     category = 'unsupervised'
     keywords = ["load", "read", "open", 'juliwenjian']
+    category = '非监督(Unsupervised)'
 
     class Outputs:
         distances = Output("距离(Distances)", DistMatrix, dynamic=False, replaces=['Distances'])
@@ -31,7 +34,7 @@ class OWDistanceFile(widget.OWWidget, RecentPathsWComboMixin):
         RecentPathsWComboMixin.__init__(self)
         self.loaded_file = ""
 
-        vbox = gui.vBox(self.controlArea, "距离文件", addSpace=True)
+        vbox = gui.vBox(self.controlArea, "距离文件")
         box = gui.hBox(vbox)
         self.file_combo.setMinimumWidth(300)
         box.layout().addWidget(self.file_combo)
@@ -47,7 +50,7 @@ class OWDistanceFile(widget.OWWidget, RecentPathsWComboMixin):
         button.setIcon(self.style().standardIcon(QStyle.SP_BrowserReload))
         button.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
 
-        box = gui.vBox(self.controlArea, "信息", addSpace=True)
+        box = gui.vBox(self.controlArea, "信息")
         self.infoa = gui.widgetLabel(box, '未加载数据。')
         self.warnings = gui.widgetLabel(box, ' ')
         #Set word wrap, so long warnings won't expand the widget
@@ -55,11 +58,11 @@ class OWDistanceFile(widget.OWWidget, RecentPathsWComboMixin):
         self.warnings.setSizePolicy(
             QSizePolicy.Ignored, QSizePolicy.MinimumExpanding)
 
-        box = gui.hBox(self.controlArea)
+        gui.rubber(self.buttonsArea)
         gui.button(
             box, self, "浏览文档数据集",
             callback=lambda: self.browse_file(True), autoDefault=False)
-        box.layout().addSpacing(200)
+        gui.rubber(self.buttonsArea)
 
         self.set_file_list()
         QTimer.singleShot(0, self.open_file)
@@ -120,7 +123,7 @@ class OWDistanceFile(widget.OWWidget, RecentPathsWComboMixin):
         except Exception as exc:
             err_value = str(exc)
             self.error("Invalid file format")
-            self.infoa.setText('由于错误，数据未加载。')
+            self.infoa.setText('错误，数据未加载。')
             self.warnings.setText(err_value)
             distances = None
 
@@ -144,5 +147,17 @@ class OWDistanceFile(widget.OWWidget, RecentPathsWComboMixin):
             self.report_items([("File name", self.loaded_file)])
 
 
+class OWDistanceFileDropHandler(SingleFileDropHandler):
+    WIDGET = OWDistanceFile
+
+    def parametersFromFile(self, path):
+        r = RecentPath(os.path.abspath(path), None, None,
+                       os.path.basename(path))
+        return {"recent_paths": [r]}
+
+    def canDropFile(self, path: str) -> bool:
+        return os.path.splitext(path)[1].lower() == ".dst"
+
+
 if __name__ == "__main__":  # pragma: no cover
     WidgetPreview(OWDistanceFile).run()
