@@ -4,17 +4,16 @@
 import unittest
 from unittest.mock import patch
 
-import numpy as np
-
 from AnyQt.QtCore import Qt, QModelIndex
+from AnyQt.QtTest import QSignalSpy
 
 from Orange.data import \
     Domain, \
     ContinuousVariable, DiscreteVariable, StringVariable, TimeVariable
 from Orange.widgets.utils import colorpalettes
 from Orange.widgets.utils.itemmodels import \
-    AbstractSortTableModel, PyTableModel,\
-    PyListModel, VariableListModel, DomainModel, ContinuousPalettesModel, \
+    PyTableModel, PyListModel, PyListModelTooltip,\
+    VariableListModel, DomainModel, ContinuousPalettesModel, \
     _as_contiguous_range
 from Orange.widgets.gui import TableVariable
 from orangewidget.tests.base import GuiTest
@@ -41,6 +40,14 @@ class TestPyTableModel(unittest.TestCase):
         self.model = PyTableModel()
         self.assertEqual(self.model.rowCount(), 0)
 
+    def test_init_wrap_empty(self):
+        # pylint: disable=protected-access
+        t = []
+        model = PyTableModel(t)
+        self.assertIs(model._table, t)
+        t.append([1, 2, 3])
+        self.assertEqual(list(model), [[1, 2, 3]])
+
     def test_rowCount(self):
         self.assertEqual(self.model.rowCount(), 2)
         self.assertEqual(len(self.model), 2)
@@ -123,6 +130,40 @@ class TestPyTableModel(unittest.TestCase):
                         self.model.data(self.model.index(1, 0),
                                         Qt.TextAlignmentRole))
 
+    def test_set_iten_slice(self):
+        self.model[:1] = [[10, 11], [12, 13], [14, 15]]
+        self.assertEqual(list(self.model), [[10, 11], [12, 13], [14, 15], [2, 3]])
+
+        self.model[1:3] = []
+        self.assertEqual(list(self.model), [[10, 11], [2, 3]])
+
+        self.model[:] = [[20, 21]]
+        self.assertEqual(list(self.model), [[20, 21]])
+
+        self.model[1:] = [[10, 11], [2, 3]]
+        self.assertEqual(list(self.model), [[20, 21], [10, 11], [2, 3]])
+
+    def test_emits_column_changes_on_row_insert(self):
+        inserted = []
+        removed = []
+        model = PyTableModel()
+        model.columnsInserted.connect(inserted.append)
+        model.columnsRemoved.connect(removed.append)
+        inserted = QSignalSpy(model.columnsInserted)
+        removed = QSignalSpy(model.columnsRemoved)
+        model.append([2])
+        self.assertEqual(list(inserted)[-1][1:], [0, 0])
+        model.append([2, 3])
+        self.assertEqual(list(inserted)[-1][1:], [1, 1])
+        del model[:]
+        self.assertEqual(list(removed)[0][1:], [0, 1])
+        model.extend([[0, 1], [0, 2]])
+        self.assertEqual(list(inserted)[-1][1:], [0, 1])
+        model.clear()
+        self.assertEqual(list(removed)[0][1:], [0, 1])
+        model[:] = [[1], [2]]
+        self.assertEqual(list(inserted)[-1][1:], [0, 0])
+
 
 class TestVariableListModel(unittest.TestCase):
     @classmethod
@@ -333,9 +374,9 @@ class TestDomainModel(unittest.TestCase):
         self.assertTrue(model.setItemData(index, {Qt.ToolTipRole: "foo"}))
 
         self.assertFalse(model.insertRows(0, 1))
-        self.assertSequenceEqual(model, domain)
+        self.assertEqual(list(model), list(domain.variables))
         self.assertFalse(model.removeRows(0, 1))
-        self.assertSequenceEqual(model, domain)
+        self.assertEqual(list(model), list(domain.variables))
 
 
 class TestContinuousPalettesModel(GuiTest):
@@ -438,5 +479,54 @@ class TestContinuousPalettesModel(GuiTest):
         self.assertIsNone(model.indexOf(42))
 
 
+class TestPyListModelTooltip(GuiTest):
+    def test_tooltips_size(self):
+        def data(i):
+            return model.data(model.index(i, 0))
+
+        def tip(i):
+            return model.data(model.index(i, 0), Qt.ToolTipRole)
+
+        # Not enough tooptips - return None
+        model = PyListModelTooltip(["foo", "bar", "baz"], ["footip", "bartip"])
+        self.assertEqual(data(1), "bar")
+        self.assertEqual(data(2), "baz")
+        self.assertIsNone(data(3))
+        self.assertEqual(tip(1), "bartip")
+        self.assertIsNone(tip(2))
+
+        # No tooltips
+        model = PyListModelTooltip(["foo", "bar", "baz"])
+        self.assertIsNone(tip(1))
+        self.assertIsNone(tip(2))
+
+        # Too many tooltips
+        model = PyListModelTooltip(["foo", "bar"], ["footip", "bartip", "btip"])
+        self.assertEqual(data(0), "foo")
+        self.assertEqual(data(1), "bar")
+        self.assertIsNone(data(2))
+        self.assertEqual(tip(1), "bartip")
+        self.assertEqual(tip(2), "btip")
+
+    def test_tooltip_arg(self):
+        def tip(i):
+            return model.data(model.index(i, 0), Qt.ToolTipRole)
+
+        # Allow generators
+        s = dict(a="ta", b="tb")
+        model = PyListModelTooltip(s, s.values())
+        self.assertEqual(tip(0), "ta")
+        self.assertEqual(tip(1), "tb")
+
+        # Basically backward compatibility; this behaviour diverges from
+        # behaviour of data role
+        s = []
+        model = PyListModelTooltip(["foo"], s)
+        self.assertIsNone(tip(0))
+
+        s += ["footip"]
+        self.assertEqual(tip(1), "footip")
+
+
 if __name__ == "__main__":
     unittest.main()
