@@ -104,7 +104,7 @@ class OWBoxPlot(widget.OWWidget):
 
     class Outputs:
         selected_data = Output(
-            "选定的数据(Selected Data)",
+            "选中的数据(Selected Data)",
             Orange.data.Table,
             default=True,
             replaces=["Selected Data"],
