@@ -779,7 +779,7 @@ class OWViolinPlot(OWWidget):
 
     class Outputs:
         selected_data = Output(
-            "选定的数据(Selected Data)",
+            "选中的数据(Selected Data)",
             Table,
             default=True,
             replaces=["Selected Data"],
