@@ -368,7 +368,7 @@ class OWDataProjectionWidget(OWProjectionWidgetBase, openclass=True):
 
     class Outputs:
         selected_data = Output(
-            "选定的数据(Selected Data)", Table, default=True, replaces=["Selected Data"]
+            "选中的数据(Selected Data)", Table, default=True, replaces=["Selected Data"]
         )
         annotated_data = Output("数据(Data)", Table, replaces=["Data"])
 
